@@ -11,6 +11,7 @@ from marshmallow import Schema
 from marshmallow import post_load
 from enum import Enum as ENUM
 from .order_item import OrderItemSchema
+from marshmallow_enum import EnumField
 
 from .base import Base
 
@@ -27,6 +28,7 @@ class Order(Base):
     __tablename__ = 'orders'
 
     id = Column(Integer, primary_key=True, autoincrement=True, nullable=False)
+    order_number = Column(String(25), nullable=False)
     user_id = Column(ForeignKey('users.id'), nullable=False, server_default='78')
     order_date = Column(DateTime, nullable=False, server_default=func.now())
     updated_date = Column(DateTime, nullable=True, server_onupdate=func.now())
@@ -47,7 +49,7 @@ class Order(Base):
     shipping_method = Column(ForeignKey('shipping_methods.id'), nullable=False)
     payment_method = Column(ForeignKey('payment_methods.id'), nullable=False)
 
-    order_items = relationship('OrderItem', foreign_keys='OrderItem.order_id')
+    order_items = relationship('OrderItem', primaryjoin='Order.id == OrderItem.order_id')
 
 
 class OrderSchema(Schema):
@@ -55,10 +57,11 @@ class OrderSchema(Schema):
     model_class = Order
 
     id = fields.Integer()
+    order_number = fields.String(data_key='orderNumber')
     user_id = fields.Integer(load_only=True, data_key='userID')
     order_date = fields.DateTime(data_key='orderDate')
     updated_date = fields.DateTime(data_key='updatedDate')
-    status = fields.String()
+    status = EnumField(OrderStatus, by_value=True)
     contact_email = fields.String(data_key='contactEmail')
     contact_phone = fields.String(data_key='contactPhone')
     shipping_name = fields.String(data_key='shippingName')
@@ -75,7 +78,7 @@ class OrderSchema(Schema):
     shipping_method = fields.Integer(data_key='shippingMethod')
     payment_method = fields.Integer(data_key='paymentMethod')
 
-    order_item = fields.Nested(OrderItemSchema)
+    order_items = fields.Nested(OrderItemSchema, many=True, data_key='orderItems')
 
     @post_load
     def make_address(self, data, **kwargs):
