@@ -3,9 +3,11 @@ from sqlalchemy import Integer
 from sqlalchemy import ForeignKey
 from sqlalchemy import String
 from sqlalchemy import Text
+from sqlalchemy.orm import relationship
 from marshmallow import fields
 from marshmallow import Schema
 from marshmallow import post_load
+from .image import ImageSchema
 
 from .base import Base
 
@@ -21,6 +23,8 @@ class Product(Base):
     quantity = Column(Integer, nullable=False)
     description = Column(Text, nullable=False)
 
+    image = relationship('Image', foreign_keys='Image.product_id')
+
 
 class ProductSchema(Schema):
 
@@ -34,6 +38,8 @@ class ProductSchema(Schema):
     quantity = fields.Integer()
     description = fields.String()
 
+    image = fields.Nested(ImageSchema)
+
     @post_load
     def make_address(self, data, **kwargs):
         return Product(**data)
